@@ -1,11 +1,23 @@
-pmpec <- function(object, data, times, model.args=NULL, type=c("PErr","NoInf"), 
-                  external.time=NULL, external.status=NULL) {
+pmpec <- function(object, response=NULL, x=NULL, times, model.args=NULL, type=c("PErr","NoInf"), 
+                  external.time=NULL, external.status=NULL, data=NULL) {
     require(survival)
-
     type <- match.arg(type)
 
-    fit.time <- data$time
-    fit.status <- data$status
+    if(is.null(response)&&is.null(x)){
+       if(!is.null(data)){
+          time <- data$time
+          status <- data$status
+          x <- data[,!(names(newdata) %in% c("time", "status"))]
+       } else {
+          stop("Please pass either arguments 'response' and 'x' or 'data'")
+       }
+    } else {
+    time <- response[, "time"]
+    status <- response[, "status"]
+    }
+
+    fit.time <- time
+    fit.status <- status
     
     if (!is.null(external.time) && !is.null(external.status)) {
         fit.time <- external.time
@@ -18,27 +30,27 @@ pmpec <- function(object, data, times, model.args=NULL, type=c("PErr","NoInf"),
     eval.cens.prob <- summary(cens.fit,times=times)$surv
     
     if (is.null(external.time) || is.null(external.status)) {
-        sortsurv <- summary(cens.fit,times=sort(data$time))$surv
-        invcensprob <- rep(NA,length(data$status))
-        invcensprob[order(data$time)] <- c(1,sortsurv[1:length(sortsurv)-1])
+        sortsurv <- summary(cens.fit,times=sort(time))$surv
+        invcensprob <- rep(NA,length(status))
+        invcensprob[order(time)] <- c(1,sortsurv[1:length(sortsurv)-1])
     } else {
         sort.time <- sort(fit.time)
         sortsurv <- c(1,summary(cens.fit,times=sort.time)$surv)
         sort.time <- c(-999,sort.time)
         sortsurv <- c(1,sortsurv)
-        invcensprob <- unlist(lapply(data$time,function(actual.time) sortsurv[which(sort.time >= actual.time)[1]-1]))
+        invcensprob <- unlist(lapply(time,function(actual.time) sortsurv[which(sort.time >= actual.time)[1]-1]))
     }
 
-    mod.time <- data$time
-    if (any(data$status > 1)) {
-        mod.time[data$status > 1] <- max(data$time,times) + 1
+    mod.time <- time
+    if (any(status > 1)) {
+        mod.time[status > 1] <- max(time,times) + 1
     }
 
-    status.mat <- matrix(times,length(data$time),length(times),byrow=TRUE) < mod.time
+    status.mat <- matrix(times,length(time),length(times),byrow=TRUE) < mod.time
 
-    probmat <- do.call("predictProb", c(list(object=object,newdata=data,times=times,learn.data=data),model.args))
+    probmat <- do.call("predictProb", c(list(object=object, response=Surv(time, status), x=x ,times=times),model.args))
 
-    weightmat <- t(t(status.mat) / eval.cens.prob) + (1 - status.mat) * matrix(data$status,length(data$status),length(times)) * matrix(1/invcensprob,length(data$status),length(times))
+    weightmat <- t(t(status.mat) / eval.cens.prob) + (1 - status.mat) * matrix(status,length(status),length(times)) * matrix(1/invcensprob,length(status),length(times))
 
     if (type == "PErr") {
         return(apply(weightmat*(status.mat - probmat)^2,2,mean))
@@ -53,7 +65,7 @@ pmpec <- function(object, data, times, model.args=NULL, type=c("PErr","NoInf"),
                   as.double(as.vector(weightmat)),
                   as.integer(as.vector(status.mat)),
                   as.double(as.vector(probmat)),
-                  as.integer(nrow(data)),
+                  as.integer(nrow(x)),
                   as.integer(length(times)),
                   err=double(length(times))
                   )
